<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet [
<!ENTITY amp   "&#38;">
<!ENTITY copy   "&#169;">
<!ENTITY gt   "&#62;">
<!ENTITY hellip "&#8230;">
<!ENTITY laquo  "&#171;">
<!ENTITY lsaquo   "&#8249;">
<!ENTITY lsquo   "&#8216;">
<!ENTITY lt   "&#60;">
<!ENTITY nbsp   "&#160;">
<!ENTITY quot   "&#34;">
<!ENTITY raquo  "&#187;">
<!ENTITY rsaquo   "&#8250;">
<!ENTITY rsquo   "&#8217;">
]>
<!--
    Implementation Skeleton Core - 11/21/18
    Standard Outputs
    Standardized outputs for implementations
-->
<xsl:stylesheet exclude-result-prefixes="xsl xs ou fn ouc" version="3.0"
    xmlns:fn="http://omniupdate.com/XSL/Functions"
    xmlns:ou="http://omniupdate.com/XSL/Variables"
    xmlns:ouc="http://omniupdate.com/XSL/Variables"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- copy meta tags from pcf, but only those with content -->
  <xsl:template name="pcf-meta-data-output">
    <xsl:apply-templates select="/document/ouc:properties[@label='metadata']/meta[@content => string-length() &gt; 0]"/>
  </xsl:template>

  <!-- direct edit default output -->
  <xsl:template name="direct-edit">
    <div id="ou-hidden" style="display:none;">
      <xsl:comment> com.omniupdate.ob </xsl:comment>
      <xsl:comment> /com.omniupdate.ob </xsl:comment>
    </div>
    <xsl:call-template name="direct-edit-script"/>
  </xsl:template>

  <!-- template that handles the direct edit script -->
  <xsl:template name="direct-edit-script">
    <script>
            if(document.getElementById(&quot;de&quot;) != null &amp;&amp; document.getElementById(&quot;directedit&quot;)) {
                var link = document.getElementById(&quot;de&quot;).parentNode.innerHTML;
                document.getElementById(&quot;de&quot;).parentNode.innerHTML = &quot;&quot;;
                document.getElementById(&quot;directedit&quot;).innerHTML = link.replace(/^\s+|\s+$/gm,'');
            }
        </script>
  </xsl:template>

  <!-- handles the output page directive for c# pages -->
  <xsl:template name="page-directive">
    <xsl:if test="($is-pub) or ($is-cmp)">
      <xsl:text disable-output-escaping="yes">&lt;%@ Page Language=&quot;C#&quot; %&gt;</xsl:text>
    </xsl:if>
    <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html&gt;</xsl:text>
  </xsl:template>

  <!-- template that handles the include statements, has conditionals for from production and condition of when it should output -->
  <xsl:template name="output-include">
    <xsl:param as="xs:string" name="path"/>
    <xsl:param as="xs:boolean" name="from-prod" select="false()"/>
    <xsl:param as="xs:boolean" name="global" select="false()"/>
    <xsl:param as="xs:boolean" name="condition" select="true()"/>
    <xsl:if test="$condition">
      <xsl:choose>
        <xsl:when test="$from-prod">
          <xsl:call-template name="unparsed-include-file">
            <xsl:with-param name="path" select="$path"/>
            <xsl:with-param name="global" select="$global"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="ou:include-file($path)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>

  <!-- template that handles the navigation output, has conditionals for from production and condition of when it should output, also has a message option for displaying a message in preview and edit -->
  <xsl:template name="output-navigation">
    <xsl:param as="xs:string" name="kind" select="'xsl'"/>
    <xsl:param as="xs:string" name="final-navigation-path" select="$navigation-path"/>
    <xsl:param as="xs:string" name="script-loc" select="''"/>
    <xsl:param as="xs:boolean" name="global" select="false()"/>
    <xsl:param as="xs:string" name="message" select="''"/>
    <xsl:param as="xs:boolean" name="debug" select="false()"/>
    <xsl:if test="$not-pub">
      <xsl:value-of disable-output-escaping="yes" select="$message"/>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$kind = 'php'">
        <xsl:choose>
          <xsl:when test="$is-pub">
            <xsl:processing-instruction name="php">
                            $nav = &quot;
              <xsl:value-of select="$final-navigation-path"/>
              &quot;;
                            $current_page = &quot;
              <xsl:value-of select="$ou:path"/>
              &quot;;
                            ?
            </xsl:processing-instruction>
            <xsl:choose>
              <xsl:when test="$global">
                <xsl:copy-of select="ou:ssi-full($script-loc)"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:copy-of select="ou:ssi($script-loc)"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="unparsed-include-file">
              <xsl:with-param name="path" select="$path"/>
              <xsl:with-param name="global" select="$global"/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="$kind = 'c#'">
        <xsl:choose>
          <xsl:when test="$is-pub">
            <xsl:text disable-output-escaping="yes">&lt;%</xsl:text>
                        OUC.NestedNav nestedNav = new OUC.NestedNav();
                        Response.Write(nestedNav.GetNav(&quot;
            <xsl:value-of select="$final-navigation-path"/>
            &quot;));
            <xsl:text disable-output-escaping="yes">%&gt;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:variable name="path" select="$script-loc || '?nav=' || $final-navigation-path || '&amp;page=' || $ou:path"/>
            <xsl:if test="$debug">
              <xsl:value-of select="'C#: ' || $path"/>
            </xsl:if>
            <xsl:call-template name="unparsed-include-file">
              <xsl:with-param name="path" select="$path"/>
              <xsl:with-param name="global" select="$global"/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="$kind = 'pcf'">
        <xsl:if test="$debug and $not-pub">
          <xsl:value-of select="'PCF: ' || $navigation-path"/>
        </xsl:if>
        <xsl:call-template name="unparsed-include-file">
          <xsl:with-param name="path" select="ou:include-file($navigation-path)"/>
          <xsl:with-param name="global" select="$global"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="$debug and $not-pub">
          <p>
            <xsl:value-of select="$dirname"/>
          </p>
          <xsl:value-of select="'Regular: ' || $navigation-path"/>
        </xsl:if>
        <xsl:copy-of select="ou:include-file($navigation-path)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
